@@ -55,7 +55,7 @@ class Build(threads.DeferredThread):
 
     def run_deferred(self):
         if self._shutdown is config.SHUTDOWN:
-            raise util.HTTPShutdown
+            raise util.HTTPShutdown()
 
         daemon.get().events.log(events.Type.BUILDING, self.breq)
         try:
