@@ -110,7 +110,7 @@ class Base(debian.deb822.Changes):
         for fd in [{"name": self.file_name()}] + self.get_files():
             f = fd["name"]
             f_abs = os.path.join(self.dir_path(), f)
-            LOG.debug("%s '{f}' to '%s'", mv.__name__, dir_path)
+            LOG.debug("%s '%s' to '%s'", mv.__name__, f, dir_path)
             mv(f_abs, os.path.join(dir_path, f))
         self.file_path = os.path.join(dir_path, self.file_name())
 
