@@ -1330,9 +1330,9 @@ class SbuildCheck():
     CHOICES = [(mode.value, mode.name) for mode in Mode]
 
     #: From sbuild source code: We may expect these textual statuses:
-    STATUSES_PASS = ["pass", "info"]
-    STATUSES_WARN = ["warn", "no tests"]
-    STATUSES_FAIL = ["error", "fail"]
+    STATUSES_PASS = ["pass", "info", "successful"]
+    STATUSES_WARN = ["warn", "no tests", "unknown"]
+    STATUSES_FAIL = ["error", "fail", "failed"]
 
     def __init__(self, checker, mode):
         if checker not in self.CHECKERS:
