@@ -267,7 +267,7 @@ class Queue(collections.deque):
 def get(events):
     event = events.get()
     if event is config.SHUTDOWN:
-        raise util.HTTPShutdown
+        raise util.HTTPShutdown()
     return event
 
 
